aboutsummaryrefslogtreecommitdiff
path: root/build2/test/script/lexer.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'build2/test/script/lexer.cxx')
-rw-r--r--build2/test/script/lexer.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/build2/test/script/lexer.cxx b/build2/test/script/lexer.cxx
index 008223c..f752f39 100644
--- a/build2/test/script/lexer.cxx
+++ b/build2/test/script/lexer.cxx
@@ -259,25 +259,25 @@ namespace build2
}
}
// Otherwise it is a name.
//
unget (c);
- return name (sep);
+ return word (sep);
}
token lexer::
- name (bool sep)
+ word (bool sep)
{
// Customized implementation that handles special variable names ($*,
// $~, $NNN).
//
if (state_.top ().mode != lexer_mode::variable)
- return base_lexer::name (sep);
+ return base_lexer::word (sep);
xchar c (peek ());
if (c != '*' && c != '~' && !digit (c))
- return base_lexer::name (sep);
+ return base_lexer::word (sep);
uint64_t ln (c.line), cn (c.column);
string lexeme;
@@ -259,25 +259,25 @@ namespace build2
}
}
- // Otherwise it is a name.
+ // Otherwise it is a word.
//
unget (c);